~ chicken-core (chicken-5) 3a35335ba8c4d66059e91f103caf43b519001d6b


commit 3a35335ba8c4d66059e91f103caf43b519001d6b
Author:     Peter Bex <peter@more-magic.net>
AuthorDate: Sat Jan 12 16:23:26 2019 +0100
Commit:     Peter Bex <peter@more-magic.net>
CommitDate: Sat Jan 12 16:23:26 2019 +0100

    Update bootstrap script to use 5.0.1 dev snapshot

diff --git a/scripts/bootstrap.sh b/scripts/bootstrap.sh
index 0adbc2b9..ff91e5ba 100755
--- a/scripts/bootstrap.sh
+++ b/scripts/bootstrap.sh
@@ -2,27 +2,27 @@
 
 set -e
 
-# build 5.0.0pre8 development snapshot
+# build 5.0.1 development snapshot
 
-mkdir -p boot/pre8
+mkdir -p boot/snapshot
 cd boot
-wget http://code.call-cc.org/dev-snapshots/2018/07/12/chicken-5.0.0pre8.tar.gz
-tar -xzf chicken-5.0.0pre8.tar.gz
-cd chicken-5.0.0pre8
-make "$@" PREFIX="$(pwd)"/../pre8
-make "$@" PREFIX="$(pwd)"/../pre8 install
+wget https://code.call-cc.org/dev-snapshots/2019/01/12/chicken-5.0.1.tar.gz
+tar -xzf chicken-5.0.1.tar.gz
+cd chicken-5.0.1
+make "$@" PREFIX="$(pwd)"/../snapshot
+make "$@" PREFIX="$(pwd)"/../snapshot install
 cd ../..
 
 # build a boot-chicken from git head using pre8 chicken and
 # then use that to build the real thing
 
 make "$@" spotless
-make "$@" CHICKEN="$(pwd)"/boot/pre8/bin/chicken boot-chicken
+make "$@" CHICKEN="$(pwd)"/boot/snapshot/bin/chicken boot-chicken
 
-# remove pre8 installation and tarball
-rm -fr boot/pre8
-rm -fr boot/chicken-5.0.0pre8
-rm -f  boot/chicken-5.0.0pre8.tar.gz
+# remove snapshot installation and tarball
+rm -fr boot/snapshot
+rm -fr boot/chicken-5.0.1
+rm -f  boot/chicken-5.0.1.tar.gz
 
 echo
 echo 'Now, build chicken by passing "CHICKEN=./chicken-boot" to make,'
@@ -2,27 +2,27 @@
 cd ../..
 
-# build a boot-chicken from git head using pre8 chicken and
-# then use that to build the real thing
+# build a boot-chicken from git head using the snapshot
+# chicken and then use that to build the real thing
 
 make "$@" spotless
Trap